#
# spec file for package blueberry
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define __requires_exclude typelib\\((St)\\)
Name:           blueberry
Version:        1.2.0
Release:        lp151.2.1
Summary:        A configuration tool for Bluetooth
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxmint/blueberry
Source:         https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE blueberry-fix-rfkill-path.patch boo#1076134 sor.alexei@meowr.ru -- Fix rfkill's path.
Patch0:         blueberry-fix-rfkill-path.patch
BuildRequires:  bluez-tools
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3
Requires:       bluez-tools
Requires:       gnome-bluetooth >= 3.14
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-setproctitle
Requires:       wmctrl
Recommends:     %{name}-lang
BuildArch:      noarch
%glib2_gsettings_schema_requires
%if 0%{?suse_version} >= 1500
Requires:       python3-dbus-python
Requires:       util-linux
%else
BuildRequires:  update-desktop-files
Requires:       dbus-1-python3
Requires:       rfkill
%endif

%description
Utility for Bluetooth devices graphical configuration.

%lang_package

%prep
%setup -q
%patch0 -p1
# Replace the icon with an existing one.
sed -i 's/^\(Icon=\).*$/\1%{name}/' .%{_datadir}/applications/%{name}.desktop

%build
make %{?_smp_mflags} V=1

%install
cp -a .%{_prefix} %{buildroot}%{_prefix}
cp -a .%{_sysconfdir} %{buildroot}%{_sysconfdir}
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc README.md debian/changelog
%{_sysconfdir}/xdg/autostart/%{name}-tray.desktop
%{_sysconfdir}/xdg/autostart/%{name}-obex-agent.desktop
%{_bindir}/%{name}*
%{_libexecdir}/%{name}/
%dir %{_datadir}/cinnamon/
%dir %{_datadir}/cinnamon/applets/
%{_datadir}/cinnamon/applets/%{name}*/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}*
%{_datadir}/glib-2.0/schemas/org.%{name}.gschema.xml

%files lang -f %{name}.lang

%changelog
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Fix some depreciation warnings.
  * Remove unused applet label.
  * applet: Use bluetooth icon, remove dangerous flag.
  * Update translations.
- Rebase blueberry-fix-rfkill-path.patch.
* Tue Jan 16 2018 sor.alexei@meowr.ru
- Add blueberry-fix-rfkill-path.patch: Fix rfkill's path
  (boo#1076134).
* Sun Dec 24 2017 sor.alexei@meowr.ru
- Update to version 1.1.20:
  * Use a regex instead of the more brittle split implementation
    (gh#linuxmint/blueberry#45).
  * Switch to Python3.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.1.19:
  * blueberry.py: Don't start blueberry-tray, it gets started on
    our behalf in the session manager since e3417c0.
  * Give blueberry-tray an application id, to prevent multiple
    instances, re-add a Popen call in blueberry.py
    (xfce session management machinery doesn't start programmes on
    the user's behalf after startup like it does in mate and
    cinnamon).
  * rfkillMagic: Use a child wrapper for the monitor subprocess.
  * Update translations.
* Thu Nov  9 2017 sor.alexei@meowr.ru
- Update to version 1.1.18:
  * Make blueberry-tray a GtkApplication and register with the
    session manager.
* Fri Nov  3 2017 sor.alexei@meowr.ru
- Update to version 1.1.17:
  * Update translations.
* Fri Oct 27 2017 sor.alexei@meowr.ru
- Update to version 1.1.16:
  * Move window declaration to init().
  * l10n: Generate desktop files.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.1.15 (changes since 1.1.13):
  * Fix unicode errors during OBEX file transfers.
  * Fix more unicode errors and missing arguments.
  * Obex: Fix non-translated strings.
  * Update translations.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Update to version 1.1.13:
  * Fix how autostart of the tray icon is handled.
  * Add exception handling around bt-adapter -i.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.1.12:
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.1.11:
  * Remove debug log
  * Add the GPLv3+ licence text.
  * Remove AutostartCondition.
  * Stop using deprecated GtkHBox and GtkVBox.
  * Bail out if something goes wrong.
  * l10n: Generate additional files.
  * Update translations.
* Fri Mar 17 2017 sor.alexei@meowr.ru
- Don't require typelib(St), provided by GNOME Shell and is always
  present with Cinnamon installed either way (required by the
  Cinnamon applet).
* Sun Feb 19 2017 sor.alexei@meowr.ru
- Update to version 1.1.10:
  * Add OBEX support.
  * Use pavucontrol for sound if present and DE isn't detected.
  * Tray: Improve the tooltip to show the name of the connected
    devices.
  * Provide a Cinnamon applet.
  * Overwrite the label in GnomeBluetooth SettingsWidget.
  * Fix Cinnamon icons.
  * Widen the default window size to 640px.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.1.9:
  * Update translations.
* Sat Nov 12 2016 sor.alexei@meowr.ru
- Update to version 1.1.8:
  * tray: Add a missing import before invocation (boo#1009912).
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.1.7:
  * Update translations.
* Wed Nov  2 2016 sor.alexei@meowr.ru
- Update to version 1.1.6:
  * Specify versions of Gtk and GnomeBluetooth before loading them
    via GI.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.1.5:
  * Rename the tray option more accurately.
  * Update translations.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 1.1.4:
  * Updated translations.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency.
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * Fix GtkStatusIcon menu popup on newer Gtk.
* Fri Apr 22 2016 sor.alexei@meowr.ru
- Update to version 1.1.2:
  * Add more padding and move the switch to the top-right corner of
    the screen (looks out of place with themes where Gtk.Switch
    isn't centered).
  * Specify gi typelib versions before importing.
  * Update translations.
  * Set up generate_desktop_files, makepot.
* Fri Feb 19 2016 sor.alexei@meowr.ru
- Update to 1.1.1:
  * Add disabled icon for bluetooth-tray.
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 1.1.0:
  * Hide in GNOME, KDE, and Unity.
  * Make blueberry-tray executable.
  * Detect more environments via $XDG_CURRENT_DESKTOP.
  * Fix monitoring settings.
  * Update translations.
* Tue Jun 30 2015 sor.alexei@meowr.ru
- Update to 1.0.9:
  * Update translations.
* Wed Jun  3 2015 sor.alexei@meowr.ru
- Update to 1.0.8:
  * Update translations.
* Fri May 29 2015 sor.alexei@meowr.ru
- Update to 1.0.7 (changes since 1.0.4):
  * List rfkill dependency.
* Tue Mar 31 2015 sor.alexei@meowr.ru
- Update to 1.0.4.
  * Unify settings getter/setter.
  * Update translations.
* Sat Mar 14 2015 sor.alexei@meowr.ru
- Initial package.
